TwitterAuth — pywws 13.06_r1023 documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »

# TwitterAuth

Autorise pywws à publier sur votre compte Twitter:

    usage: python -m pywws.TwitterAuth [options] data_dir
    options are:
     -h or --help       display this help
    data_dir is the root directory of the weather data

Ce programme autorise `pywws.ToTwitter` à poster sur un compte Twitter. Vous devez créer un compte avant de lancer `TwitterAuth`. Il ouvre une fenêtre de navigateur Web (ou vous donne une URL à copier dans votre navigateur) où vous vous connectez à votre compte Twitter. Si la connexion est réussie, le navigateur affichera un nombre à 7 chiffres, que vous devrez copier dans `TwitterAuth`.

Voir Comment configurer pywws pour poster des messages sur Twitter pour plus de détails sur l’utilisation de Twitter avec pywws.

Fonctions

`TwitterAuth`(params) |
`main`([argv]) |

`pywws.TwitterAuth.` `TwitterAuth`(params)

`pywws.TwitterAuth.` `main`(argv=None)

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »